#!/usr/bin/perl -w

push @SPECHOOKS, 
sub {
    my ($spec,) = @_;
    my $logfile;
    my $container_opt=$RPM::Source::Transformation::HookWrapper::opt;
    if ($container_opt) {
	my $env=$container_opt->{-hooks_environment_for_package};
	$logfile=$env->{'LOGOVED_LOGFILE'} if $env;
    }
    unless (defined($logfile)) {
	my $logdir='OUT-hsh.logs-failure';
	$logdir=$ENV{'LB_REBUILD_LOGDIR'} if $ENV{'LB_REBUILD_LOGDIR'};
	$logfile=$spec->macros()->macro_subst_if_defined($logdir.'/%name-%version-%release.src.rpm.log');
	#print STDERR "looking for $logfile\n";
    }
    return unless defined($logfile) and -e $logfile;
    my $mainsec=$spec->main_section;
    my $filessec=$spec->get_section('files','');
    my $instsec=$spec->get_section('install');
    my $build_arch=$mainsec->get_tag('BuildArch');
    my $noarch=1 if $build_arch and $build_arch eq 'noarch';
    open(my $fn,'<', $logfile) || die "$! [$logfile].  Stopped ";
    my $flag=0;
    my ($auto,$autoshare);
    my %prefix;
    my %archprefix;
    my ($perldatamodules,$perllocaledata);
    while(<$fn>) {
	next if $flag>1;
	unless (m!^Installing /usr/src/tmp/[^/]+-buildroot(.*\S)\s*$!) {
	    $flag=2 if 1==$flag;
	    next;
	} else {
	    $instpath=$1;
	    $_=$1;
	    $flag=1;
	    if (m!^/usr/share/perl5/auto/!) {
		$autoshare=1;
	    } elsif (m!^none!) {
		    $instsec->push_body('rm -rf %{buildroot}none*'.$1."\n");
	    } elsif (m!^/usr/lib(?:64)?/perl5/auto!) {
		$auto=1;
	    } elsif (m!^/usr/share/perl5/data/modules!) {
		$perldatamodules=1;
	    } elsif (m!^/usr/share/perl5/LocaleData!) {
		$perllocaledata=1;
	    } elsif (m!^/usr/share/perl5/(.)!) {
		$prefix{$1}=1;
	    } elsif (m!^/usr/lib(?:64)?/perl5/(.)!) {
		$archprefix{$1}=1;
	    }
	}
    }
    close($fn);
    $filessec->push_body('%perl_vendor_privlib/auto/*'."\n") if $autoshare;
    $filessec->push_body('%perl_vendor_archlib/auto/*'."\n") if $auto;
    $filessec->push_body('%perl_vendor_privlib/data/modules/*'."\n") if $perldatamodules;
    # TODO find-lang
    $filessec->push_body('%perl_vendor_privlib/LocaleData/*'."\n") if $perllocaledata;
    foreach my $prefix (keys(%prefix)) {
	$filessec->push_body('%perl_vendor_privlib/'.$prefix.'*'."\n");
    }
    foreach my $prefix (keys(%archprefix)) {
	$filessec->push_body('%perl_vendor_archlib/'.$prefix.'*'."\n");
    }
    if ($noarch) {
	$mainsec->exclude_body(qr'^BuildArch\s*:\s*noarch') if $auto or %archprefix;
    } else {
	#$mainsec->push_body('BuildArch: noarch'."\n") unless $auto or %archprefix;
    }
    if ($autoshare or $auto or $perldatamodules or $perllocaledata or %prefix or %archprefix) {
	$filessec->exclude_body('OOPS_NOTHING_TO_PACKAGE');
    }
};

__END__
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/auto/Prima/IPA/IPA.so
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Geometry/GeometrySupp.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Misc/MiscSupp.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Global/GlobalSupp.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Global/gsclose.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Local/LocalSupp.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Point/PointSupp.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Morphology/thin.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Morphology/thin1.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/Prima/IPA/Morphology/MorphologySupp.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/Local.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/Global.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/Geometry.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/Region.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/Misc.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/Point.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/Morphology.pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/CORE/IPAsupp.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/CORE/generic/Local.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/CORE/generic/Morphology.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/CORE/generic/Global.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/CORE/generic/Point.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/CORE/generic/Geometry.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/lib/perl5/Prima/IPA/CORE/generic/Misc.h
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/share/man/man1/iterm.1
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA::Point.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA::Morphology.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA::Misc.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA::Local.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA::Region.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA::Global.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildrootnone/Prima::IPA::Geometry.3pm
Installing /usr/src/tmp/perl-Prima-IPA-buildroot/usr/bin/iterm
