#!/usr/bin/perl -w

push @SPECHOOKS, 
sub {
    my ($spec,) = @_;
    my $logfile;
    my $container_opt=$RPM::Source::Transformation::HookWrapper::opt;
    if ($container_opt) {
	my $env=$container_opt->{-hooks_environment_for_package};
	$logfile=$env->{'LOGOVED_LOGFILE'} if $env;
    }
    unless (defined($logfile)) {
	my $logdir='OUT-hsh.logs-failure';
	$logdir=$ENV{'LB_REBUILD_LOGDIR'} if $ENV{'LB_REBUILD_LOGDIR'};
	$logfile=$spec->macros()->macro_subst_if_defined($logdir.'/%name-%version-%release.src.rpm.log');
	#print STDERR "looking for $logfile\n";
    }
    return unless defined($logfile) and -e $logfile;
    my $filessec=$spec->get_section('files','');
    my $prepsec=$spec->get_section('prep');
    my $instsec=$spec->get_section('install');
    open(my $fn,'<', $logfile) || die "$! [$logfile].  Stopped ";
    my %add;
    my $flaglist=0;
    my ($auto,$man1,$man3,$bin,$oops);
    my %prefix;
    my %archprefix;
    my %shareprefix;
    my ($perldatamodules,$perllocaledata,$varwww);
    my $macos_fs;
    while(<$fn>) {
	if (not $flaglist and m!warning: Installed \(but unpackaged\) file\(s\) found:!) {
	    $flaglist=1;
	    next;
	}
	if ($flaglist == 1) {
	    if (not m!^    /!) {
		$flaglist=2;
		next;
	    } else {
		s,^\s*,,;
		s,\s*$,,;
		if (m!^/usr/share/perl5/auto/!) {
		    $auto=1;
		} elsif (m!^/usr/(?:lib64|lib|share)/perl5/(\.DS_Store|TODO|README\.pod)$!) {
		    $instsec->push_body('rm %buildroot%perl_vendor_privlib/'.$1."\n");
		} elsif (m!^/usr/(?:lib64|lib|share)/perl5/(.*/\.DS_Store)$!) {
		    $instsec->push_body('rm -f %buildroot%perl_vendor_privlib/'.$1."\n");
		} elsif (m!^/usr/share/perl5/bin/!) {
		    $instsec->push_body('rm -r %buildroot%perl_vendor_privlib/bin/'."\n");
		} elsif (m!^/usr/share/perl5(.*/Makefile(?:.old)?)$!) {
		    $instsec->push_body('rm -r %buildroot%perl_vendor_privlib/'.$1."\n");
		} elsif (m!^/usr/(?:lib(?:64)?|share)/perl5/\._.*\.(pm|pod)!) {
		    $macos_fs=1;
		} elsif (m!^/usr/(?:lib(?:64)?|share)/perl5/\._.*DS_Store!) {
		    $macos_fs=1;
		} elsif (m!^/usr/share/perl5/(.).*\.pmc?!) {
		    $prefix{$1}=1;
		} elsif (m!^/usr/share/perl5/(.).*\.pod!) {
		    $prefix{$1}=1;
		} elsif (m!^/usr/share/perl5/(.).*\.ph!) {
		    $prefix{$1}=1;
		} elsif (m!^/usr/lib(?:64)?/perl5/(.).*\.pmc?!) {
		    $archprefix{$1}=1;
		} elsif (m!^/usr/lib(?:64)?/perl5/(.).*\.pod!) {
		    $archprefix{$1}=1;
		} elsif (m!^/usr/share/perl5/data/modules/!) {
		    $perldatamodules=1;
		} elsif (m!^/usr/share/perl5/LocaleData/!) {
		    $perllocaledata=1;
		} elsif (m!^/usr/share/perl5/([^/\.]+)$!) {
		    $instsec->push_body('rm -f %buildroot%perl_vendor_privlib/'.$1."\n");
#		} elsif (m!^/usr/share/perl5/sample.*\.pl$!) {
#		    $instsec->push_body('rm %buildroot%perl_vendor_privlib/sample*.pl'."\n");
#		} elsif (m!^/usr/share/perl5/test.*\.pl$!) {
#		    $instsec->push_body('rm %buildroot%perl_vendor_privlib/test*.pl'."\n");
		} elsif (m!^/usr/share/perl5/([^/]+\.pl)$!) {
		    $instsec->push_body('rm -f %buildroot%perl_vendor_privlib/'.$1."\n");
		} elsif (m!^/usr/share/man/man3!) {
		    $man3=1;
		} elsif (m!^/blib/cgi!) {
		    $instsec->push_body('rm -rf %buildroot/blib'."\n");
		} elsif (m!^/usr/share/perl5/(t/.*\.t)$!) {
		    $instsec->push_body('rm -f %buildroot/%perl_vendor_privlib/'."$1\n");
		} elsif (m!^/var/www/!) {
		    $varwww=1;
		} elsif (m!^/usr/etc/!) {
		    $usretc=1;
		} elsif (m!^/usr/share/man/man1!) {
		    $man1=1;
		} elsif (m!^/usr/bin/!) {
		    $bin=1;
		} elsif (m!^/usr/share/(doc|locale|man|info)/!) {
		    $oops=1;
		} elsif (m!^/usr/share/([a-zA-Z1-9_]*)/!) {
		    $shareprefix{$1}=1 if $1 ne 'perl5';
		} elsif (m!^(/etc/.*\.(?:conf|cfg))$!) {
		    $filessec->push_body($1."\n");
		} else {
		    $oops=1;
		    print "Oops: $_ - not supported!\n";
		}		
	    }
	}
    }
    close($fn);
    my $scriptsec=$spec->get_section('files','scripts');
    if (not $oops) {
	if (not $scriptsec and $bin) {
	    $spec->get_section('package','')->unshift_body('BuildRequires: perl-podlators'."\n");
	    $spec->get_section('description','')->push_body(q!
%package scripts
Summary: %name scripts
Group: Development/Perl
Requires: %name = %EVR

%description scripts
scripts for %name
!."\n");
	    $spec->get_section('files')->push_body(q!
%files scripts
%_bindir/*
%_man1dir/*
!."\n");
	}
	$prepsec->push_body(q{find . -name '._*' -print -delete}) if $macos_fs;
	if ($man1) {
	    if ($scriptsec) {
		$scriptsec->push_body('%_man1dir/*'."\n");
	    } else {
		$filessec->push_body('%_man1dir/*'."\n");
	    }
	}
	$instsec->push_body('rm -rf %buildroot%_man3dir'."\n") if $man3;
	$filessec->push_body('%perl_vendor_privlib/auto/*'."\n") if $auto;
	$filessec->push_body('%perl_vendor_privlib/data/modules/*'."\n") if $perldatamodules;
	$filessec->push_body('/var/www/*'."\n") if $varwww;
	$filessec->push_body('/usr/etc/*'."\n") if $usretc;
	# TODO find-lang
	$filessec->push_body('%perl_vendor_privlib/LocaleData/*'."\n") if $perllocaledata;
	foreach my $prefix (keys(%prefix)) {
	    $filessec->push_body('%perl_vendor_privlib/'.$prefix.'*'."\n");
	}
	foreach my $prefix (keys(%archprefix)) {
	    $filessec->push_body('%perl_vendor_archlib/'.$prefix.'*'."\n");
	}
	foreach my $prefix (keys(%shareprefix)) {
	    $filessec->push_body('%_datadir/'.$prefix."\n");
	}
    }
};

__END__
